@@ -5,14 +5,14 @@ use warnings;
 
 package Map::Metro {
 
-    our $VERSION = '0.2207'; # VERSION
+    our $VERSION = '0.2208'; # VERSION
     # ABSTRACT: Public transport graphing
     use Moose;
     use Module::Pluggable search_path => ['Map::Metro::Plugin::Map'], require => 1, sub_name => 'system_maps';
     use MooseX::AttributeShortcuts;
     use Types::Standard -types;
     use Types::Path::Tiny -types;
-    use List::AllUtils 'any';
+    use List::Util 1.33 'any';
 
     use Map::Metro::Graph;
 
@@ -131,9 +131,24 @@ __END__
 
 Map::Metro - Public transport graphing
 
+
+
+=begin HTML
+
+<p><img src="https://img.shields.io/badge/perl-5.16-brightgreen.svg" alt="Requires Perl 5.16" /> <a href="https://travis-ci.org/Csson/p5-Map-Metro"><img src="https://api.travis-ci.org/Csson/p5-Map-Metro.svg?branch=master" alt="Travis status" /></a></p>
+
+=end HTML
+
+
+=begin markdown
+
+![Requires Perl 5.16](https://img.shields.io/badge/perl-5.16-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Map-Metro.svg?branch=master)](https://travis-ci.org/Csson/p5-Map-Metro)
+
+=end markdown
+
 =head1 VERSION
 
-Version 0.2207, released 2015-03-03.
+Version 0.2208, released 2015-10-27.
 
 =head1 SYNOPSIS
 
