@@ -2,13 +2,13 @@ use Map::Metro::Standard::Moops;
 use strict;
 use warnings;
 
-our $VERSION = '0.2207'; # VERSION
+our $VERSION = '0.2208'; # VERSION
 # PODNAME: Map::Metro::Cmd::Lines
 
 class Map::Metro::Cmd::Lines extends Map::Metro::Cmd using Moose {
 
     use MooseX::App::Command;
-    use List::AllUtils 'all';
+    use List::Util 1.33 'all';
 
     parameter cityname => (
         is => 'rw',
@@ -72,7 +72,7 @@ Map::Metro::Cmd::Lines
 
 =head1 VERSION
 
-Version 0.2207, released 2015-03-03.
+Version 0.2208, released 2015-10-27.
 
 =head1 SOURCE
 
