@@ -2,13 +2,13 @@ use Map::Metro::Standard;
 use strict;
 use warnings;
 
-our $VERSION = '0.2207'; # VERSION
+our $VERSION = '0.2208'; # VERSION
 
 package Map::Metro::Emitter {
 
     use Moose;
     use Kavorka;
-    use List::AllUtils 'none';
+    use List::Util 1.33 'none';
     use Types::Standard -types;
     use Map::Metro::Hook;
 
@@ -98,7 +98,7 @@ Map::Metro::Emitter
 
 =head1 VERSION
 
-Version 0.2207, released 2015-03-03.
+Version 0.2208, released 2015-10-27.
 
 =head1 SOURCE
 
