@@ -2,7 +2,7 @@ use Map::Metro::Standard::Moops;
 use strict;
 use warnings;
 
-our $VERSION = '0.2207'; # VERSION
+our $VERSION = '0.2208'; # VERSION
 # PODNAME: Map::Metro::Plugin::Hook::PrettyPrinter
 
 class Map::Metro::Plugin::Hook::PrettyPrinter using Moose {
@@ -47,11 +47,16 @@ class Map::Metro::Plugin::Hook::PrettyPrinter using Moose {
                 push @rows => '';
             }
 
-            my @lines_in_routing = uniq sort { $a->name cmp $b->name } map { $_->origin_line_station->line } map { $_->all_steps } $routing->all_routes;
+            my @lines_in_routing = sort { $a->name cmp $b->name } map { $_->origin_line_station->line } map { $_->all_steps } $routing->all_routes;
 
-            LINE:
-            foreach my $line (@lines_in_routing) {
-                push @rows => sprintf "%-${longest_length}s  %s", $line->name, $line->description;
+            {
+                my %seen_lines = ();
+                LINE:
+                foreach my $line (@lines_in_routing) {
+                    next LINE if exists $seen_lines{ $line };
+                    $seen_lines{ $line } = 1;
+                    push @rows => sprintf "%-${longest_length}s  %s", $line->name, $line->description;
+                }
             }
 
             push @rows => '', '*: Transfer to other line', '+: Transfer to other station', '';
@@ -60,7 +65,6 @@ class Map::Metro::Plugin::Hook::PrettyPrinter using Moose {
 
         };
     }
-
 }
 
 1;
@@ -77,7 +81,7 @@ Map::Metro::Plugin::Hook::PrettyPrinter
 
 =head1 VERSION
 
-Version 0.2207, released 2015-03-03.
+Version 0.2208, released 2015-10-27.
 
 =head1 SOURCE
 
