@@ -2,13 +2,13 @@ use 5.16.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.2207'; # VERSION
+our $VERSION = '0.2208'; # VERSION
 
 package #
     Map::Metro::Standard::Moops {
 
     use base 'Moops';
-    use List::AllUtils();
+    use List::Util 1.33 ();
     use Map::Metro::Types();
     use Eponymous::Hash();
     use List::Compare();
@@ -20,7 +20,7 @@ package #
         my %opts = @_;
 
         push @{ $opts{'imports'} ||= [] } => (
-            'List::AllUtils'    => [qw/any none sum uniq/],
+            'List::Util'        => [qw/any none sum/],
             'Eponymous::Hash'   => ['eh'],
             'String::Trim'      => ['trim'],
             'feature'           => [qw/:5.16/],
@@ -48,7 +48,7 @@ Map::Metro::Standard::Moops
 
 =head1 VERSION
 
-Version 0.2207, released 2015-03-03.
+Version 0.2208, released 2015-10-27.
 
 =head1 SOURCE
 
